package de.iflow.flashlight;

import android.hardware.Camera;
import android.hardware.Camera.Parameters;
import de.iflow.components.IFlowApplication;
import de.iflow.flashlight.messages.ReqTurnOff;
import de.iflow.flashlight.messages.ReqTurnOn;
import de.iflow.flashlight.messages.TurnOff;
import de.iflow.flashlight.messages.TurnOn;
import de.iflow.util.IFlowUtil;

public class Flashlight extends IFlowApplication {

	private static Flashlight instance;
	
	private Camera cam;

	// constructor can't be private in android
	public Flashlight() {
		// Activity is automatically called/created by the Android Framework
		// set reference to object with keyword this
		instance = this;
	}

	// then it's not really a singleton pattern...
	public static Flashlight getInstance() {
		// in android instance won't be null, if activity is created
		if (instance == null) {
			instance = new Flashlight();
		}
		return instance;
	}

	/*
	 * Implement abstract methods from inherited abstract parent
	 */

	@Override
	public void init() {
		IFlowUtil.log("init");
		User.getInstance().confirmTurnOn(new ReqTurnOn());
	}

	@Override
	protected void storeData() {
	}

	@Override
	protected void restoreData() {
	}

	@Override
	protected void handleIntentExtras() {
	}
	
	
	/*
	 * Flashlight app message functions 
	 */
	public void turnOn(TurnOn message)
	{
		getInstance().turnOn();
		User.getInstance().confirmTurnOff(new ReqTurnOff());
	}
	
	public void turnOff(TurnOff message)
	{
		getInstance().turnOff();;
		User.getInstance().confirmTurnOn(new ReqTurnOn());
	}
	
	
	/*
	 * Hardware functions to turn cam on and off
	 */
	private void turnOn()
	{
		cam = Camera.open();     
		Parameters p = cam.getParameters();
		p.setFlashMode(Parameters.FLASH_MODE_TORCH);
		cam.setParameters(p);
		cam.startPreview();
	}
	
	private void turnOff()
	{
		cam.stopPreview();
		cam.release();
	}
}
